@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher::AO3;
-$WWW::FetchStory::Fetcher::AO3::VERSION = '0.1826';
+$WWW::FetchStory::Fetcher::AO3::VERSION = '0.1827';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1826
+version 0.1827
 
 =head1 DESCRIPTION
 
@@ -142,7 +142,10 @@ sub parse_toc {
     $info{rating} = $self->parse_rating(%args);
     $info{chapters} = $self->parse_chapter_urls(%args, sid=>$sid);
     #$info{epub_url} = $self->parse_epub_url(%args, sid=>$sid);
-    $info{wordcount} = $self->parse_wordcount(%args);
+    if ($info{epub_url})
+    {
+        $info{wordcount} = $self->parse_wordcount(%args);
+    }
 
     return %info;
 } # parse_toc
@@ -210,7 +213,7 @@ sub parse_title {
     my $content = $args{content};
 
     my $title = '';
-    if ($content =~ m!&lt;a href=&quot;http://archiveofourown.org/works/\d+&quot;&gt;&lt;strong&gt;([-\s\w]+)&lt;/strong&gt;&lt;/a&gt;!)
+    if ($content =~ m!&lt;a href=&quot;http://archiveofourown.org/works/\d+&quot;&gt;&lt;strong&gt;(.*?)&lt;/strong&gt;&lt;/a&gt;!)
     {
 	$title = $1;
     }
@@ -343,7 +346,11 @@ sub parse_universe {
     my $content = $args{content};
 
     my $universe = '';
-    if ($content =~ m!^Fandom: (&lt;a href=&quot;http://archiveofourown.org/tags/.*?,.*?)$!m)
+    if ($content =~ m!Fandom: &lt;a href=&quot;http://archiveofourown\.org/tags/.*?&quot;&gt;(.*?)&lt;/a&gt!)
+    {
+        $universe = $1;
+    }
+    elsif ($content =~ m!^Fandom: (&lt;a href=&quot;http://archiveofourown.org/tags/.*?,.*?)$!m)
     {
 	my $fandoms = $1;
 	my @fds = split(/,/, $fandoms);
@@ -365,6 +372,10 @@ sub parse_universe {
     {
 	$universe = $self->SUPER::parse_universe(%args);
     }
+    if ($universe =~ m!Harry Potter - J\. K\. Rowling!)
+    {
+        $universe =~ s/\s*-\s*J\. K\. Rowling//;
+    }
     return $universe;
 } # parse_universe
 
